==========================
Glossaire
==========================

.. glossary::

	serveur-client
		Architecture de système très courante, où un ou plusieurs programmes
		clients envoient des requêtes et attendent des réponses d'un programme
		serveur.